import { reactive, onMounted, ref, ElMessage, ElMessageBox, http, getGroupUrl, RegularVerification, verification, PaginationProps } from "@/utils/importUsed"
// 表单实例
const ruleFormRef = ref()
export function useAppBottomNavs() {
  // 接口列表实例
  let UrlList = reactive(null)
  // 获取当前板块接口列表
  onMounted(async () => {
    UrlList = await getGroupUrl(["kxsConfigServer"]);
    onSearch(ruleFormRef.value);

  });
  let form = reactive({
    kind: "creater", //分类
    appVersion: "",

  });
  const dataList = ref([]);
  const loading = ref(false);
  const dialogAddVisible = ref(false);
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 10,
    currentPage: 1,
    background: true
  });
  const columns: TableColumnList = [
    {
      type: "selection",
      width: 55,
      align: "left",
      hide: ({ checkList }) => !checkList.includes("勾选列")
    },
    {
      label: "序号",
      type: "index",
      width: 70,
      hide: ({ checkList }) => !checkList.includes("序号列")
    },
    {
      label: "ID",
      prop: "id",
      minWidth: 200
    },
    {
      label: "标题",
      prop: "title",
      minWidth: 200
    },
    {
      label: "选中图标",
      prop: "selectIcon",
      minWidth: 200
    },
    {
      label: "未选中图标",
      prop: "normalIcon",
      minWidth: 200
    },
    {
      label: "选中文字颜色",
      prop: "selectTextColor",
      minWidth: 200
    },
    {
      label: "未选中文字颜色",
      prop: "normalTextColor",
      minWidth: 200
    },
    {
      label: "关联页面文件",
      prop: "pageName",
      minWidth: 200
    },
    {
      label: "空页面提示信息",
      prop: "noPageHint",
      minWidth: 200
    },
    {
      label: "背景色",
      prop: "backgroudColor",
      minWidth: 200
    },
    {
      label: "按钮样式",
      prop: "style",
      minWidth: 200
    },

    {
      label: "操作",
      fixed: "right",
      width: 200,
      slot: "operation"
    }
  ];
  // 当前页数量切换
  function handleSizeChange(val: number) {
    if (typeof val === "number") {
      pagination.pageSize = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 当前页码切换
  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
    if (typeof val === "number") {
      pagination.currentPage = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 选择表格项
  function handleSelectionChange(val) {
    console.log(`SelectionChange: ${val}`);
    onSearch(ruleFormRef.value);
  }
  // 搜索列表
  async function onSearch(formEl) {
    // 表单校验拦截
    if (!formEl) return
    await formEl.validate(async (valid, fields) => {
      if (valid) {
        //表单校验成功回调
        console.log('submit!')
        // 状态调整为加载中
        loading.value = true;
        // 调用接口（需动态生成接口）
        const { status, msg, data }: any = await http.Request({
          method: UrlList.kxsConfigServer.appBottomNavslist.method,
          url: UrlList.kxsConfigServer.appBottomNavslist.url,
          params: {
            ...form,
            pageSize: pagination.pageSize,
            pageNum: pagination.currentPage
          }
        });
        dataList.value = data.records;
        pagination.total = data.total;
        setTimeout(() => {
          loading.value = false;
        }, 500);
      } else {
        //表单校验失败回调
        ElMessage({
          message: "请输入完整信息",
          type: "error"
        });
      }
    })
  }



  // 删除
  function handleDelete(row) {
    ElMessageBox.confirm(
      `是否删除该app底部导航? `,
      "提示",
      {
        confirmButtonText: "删除",
        cancelButtonText: "取消",
        type: "warning"
      }
    ).then(async () => {
      const { status, msg }: any = await http.Request({ method: UrlList.kxsConfigServer.appBottomNavsdelete.method, url: UrlList.kxsConfigServer.appBottomNavsdelete.url, params: String(row.id) });
      if (status === 1) {
        ElMessage({
          message: "删除成功",
          type: "success"
        });
        onSearch(ruleFormRef.value);
      } else {
        ElMessageBox.alert(msg, "提示", {
          confirmButtonText: "关闭",
          type: "warning"
        });
      };
    })
  }

  // 新增
  const addVisible = ref(false);
  function handleAdd() {
    addVisible.value = true;
  };

  // 修改
  const editUpdateVisible = ref(false);
  const editUpdateFormData = ref({});
  function handleUpdate(row) {
    editUpdateVisible.value = true;
    // 表格数据赋值
    editUpdateFormData.value = row;
  };

  // 分类选项数据
  const kindOptionList = [
    { label: '创客版', id: 'creater' }
  ]

  return {
    form,
    loading,
    columns,
    dataList,
    pagination,
    onSearch,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    kindOptionList,
    ruleFormRef,

    handleAdd,
    addVisible,
    handleUpdate,
    editUpdateVisible,
    editUpdateFormData,
    handleDelete,

  };
}
