import {
  reactive,
  onMounted,
  ref,
  ElMessage,
  ElMessageBox,
  http,
  getGroupUrl,
  RegularVerification,
  verification,
  PaginationProps
} from "@/utils/importUsed";
// 表单实例
const ruleFormRef = ref();
export function useAppBottomNavs() {
  // 接口列表实例
  let UrlList = reactive(null);
  // 获取当前板块接口列表
  onMounted(async () => {
    UrlList = await getGroupUrl(["kxsConfigServer"]);
    onSearch(ruleFormRef.value);
  });
  const form = reactive({
    // kind: "creater", // 分类
    appVersion: "", // 上报版本号
    userTag: "", // 用户标识
    pageTitle: "", // 页面标题
    pageUrl: "", // 页面地址
    deviceSize: "", // 设备尺寸
    reportType: "" // 上报类型
  });
  const dataList = ref([]);
  const loading = ref(false);
  const dialogAddVisible = ref(false);
  const pagination = reactive<PaginationProps>({
    total: 0,
    pageSize: 30,
    currentPage: 1,
    background: true,
    pageSizes: [10, 30, 50, 100]
  });
  const columns: TableColumnList = [
    {
      type: "selection",
      width: 55,
      align: "left",
      hide: ({ checkList }) => !checkList.includes("勾选列")
    },
    {
      label: "序号",
      type: "index",
      width: 70,
      hide: ({ checkList }) => !checkList.includes("序号列")
    },
    {
      label: "页面标题",
      prop: "pageTitle",
      minWidth: 200
    },
    {
      label: "页面地址",
      prop: "pageUrl",
      minWidth: 200
    },
    {
      label: "用户系统信息",
      prop: "userSysInfo",
      minWidth: 200
    },
    {
      label: "设备尺寸",
      prop: "deviceSize",
      minWidth: 200
    },
    {
      label: "上报类型",
      prop: "reportType",
      minWidth: 200
    },
    {
      label: "上报数据",
      prop: "reportData",
      minWidth: 200
    },
    {
      label: "用户标识",
      prop: "userTag",
      minWidth: 200
    },
    {
      label: "创建时间",
      prop: "createTime",
      minWidth: 200
    },
    {
      label: "ID",
      prop: "id",
      minWidth: 200
    }

    // {
    //   label: "操作",
    //   fixed: "right",
    //   width: 200,
    //   slot: "operation"
    // }
  ];
  // 当前页数量切换
  function handleSizeChange(val: number) {
    if (typeof val === "number") {
      pagination.pageSize = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 当前页码切换
  function handleCurrentChange(val: number) {
    console.log(`current page: ${val}`);
    if (typeof val === "number") {
      pagination.currentPage = val;
      onSearch(ruleFormRef.value);
    }
  }
  // 选择表格项
  function handleSelectionChange(val) {
    console.log(`SelectionChange: ${val}`);
    onSearch(ruleFormRef.value);
  }
  // 搜索列表
  async function onSearch(formEl) {
    // 表单校验拦截
    if (!formEl) return;
    await formEl.validate(async (valid, fields) => {
      if (valid) {
        //表单校验成功回调
        console.log("submit!");
        // 状态调整为加载中
        loading.value = true;
        // 调用接口（需动态生成接口）
        const { status, msg, data }: any = await http.Request({
          method: "get",
          url: "https://test-app-manager.kexiaoshuang.com/v1/api/AppReportRecord/getAppReportRecordList",
          // method: UrlList.kxsConfigServer.appBottomNavslist.method,
          // url: UrlList.kxsConfigServer.appBottomNavslist.url,
          params: {
            ...form,
            pageSize: pagination.pageSize,
            pageNum: pagination.currentPage
          }
        });
        dataList.value = data.records;
        pagination.total = data.total;
        setTimeout(() => {
          loading.value = false;
        }, 500);
      } else {
        //表单校验失败回调
        ElMessage({
          message: "请输入完整信息",
          type: "error"
        });
      }
    });
  }

  // 删除
  function handleDelete(row) {
    ElMessageBox.confirm(`是否删除该app底部导航? `, "提示", {
      confirmButtonText: "删除",
      cancelButtonText: "取消",
      type: "warning"
    }).then(async () => {
      const { status, msg }: any = await http.Request({
        method: UrlList.kxsConfigServer.appBottomNavsdelete.method,
        url: UrlList.kxsConfigServer.appBottomNavsdelete.url,
        params: String(row.id)
      });
      if (status === 1) {
        ElMessage({
          message: "删除成功",
          type: "success"
        });
        onSearch(ruleFormRef.value);
      } else {
        ElMessageBox.alert(msg, "提示", {
          confirmButtonText: "关闭",
          type: "warning"
        });
      }
    });
  }

  // 分类选项数据
  const kindOptionList = [{ label: "创客版", id: "creater" }];

  return {
    form,
    loading,
    columns,
    dataList,
    pagination,
    onSearch,
    handleSizeChange,
    handleCurrentChange,
    handleSelectionChange,
    kindOptionList,
    ruleFormRef,
    handleDelete
  };
}
